/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.samplejsffacelets.portlet;

import java.io.IOException;

import javax.portlet.PortletException;
import javax.portlet.PortletMode;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.portlet.UnavailableException;

/**
 * @author Raymond Augé
 */
public class MyFacesFaceletsPortlet
	extends org.apache.myfaces.portlet.MyFacesGenericPortlet {

	@Override
	public void init() throws PortletException, UnavailableException {
		_editPage = getInitParameter("EditPage");
		_helpPage = getInitParameter("HelpPage");
		_viewPage = getInitParameter("ViewPage");

		super.init();
	}

	@Override
	public void render(
			RenderRequest renderRequest, RenderResponse renderResponse)
		throws IOException, PortletException {

		PortletSession portletSession = renderRequest.getPortletSession();

		PortletMode mode = (PortletMode)portletSession.getAttribute(
			"CurrentPortletMode");

		if (mode == null) {
			mode = renderRequest.getPortletMode();
		}

		if (mode != renderRequest.getPortletMode()) {
			renderRequest.setAttribute("isPortletModeChanged", Boolean.TRUE);
		}
		else {
			renderRequest.setAttribute("isPortletModeChanged", Boolean.FALSE);
		}

		portletSession.setAttribute("CurrentPortletMode", mode);

		super.render(renderRequest, renderResponse);
	}

	@Override
	protected void setDefaultView() throws UnavailableException {
		defaultView = getPortletConfig().getInitParameter(DEFAULT_VIEW);

		if (defaultView == null) {
			defaultView = _viewPage;
		}

		if (defaultView == null) {
			throw new UnavailableException(
				"Default JSF view is not specified in portlet.xml");
		}
	}

	@Override
	protected void doEdit(
			RenderRequest renderRequest, RenderResponse renderResponse)
		throws IOException, PortletException {

		Boolean isPortletModeChanged =
			(Boolean)renderRequest.getAttribute("isPortletModeChanged");

		if (isPortletModeChanged.booleanValue()) {
			setPortletRequestFlag(renderRequest);
			nonFacesRequest(renderRequest, renderResponse, _editPage);

			return;
		}

		facesRender(renderRequest, renderResponse);
	}

	@Override
	protected void doHelp(
			RenderRequest renderRequest, RenderResponse renderResponse)
		throws IOException, PortletException {

		Boolean isPortletModeChanged =
			(Boolean)renderRequest.getAttribute("isPortletModeChanged");

		if (isPortletModeChanged.booleanValue()) {
			setPortletRequestFlag(renderRequest);
			nonFacesRequest(renderRequest, renderResponse, _helpPage);

			return;
		}

		facesRender(renderRequest, renderResponse);
	}

	private String _editPage = null;
	private String _helpPage = null;
	private String _viewPage = null;

}